Cartesian Skepticism - Neo, Meet Rene: Crash Course Philosophy #5

CrashCourse

Cartesian Skepticism - Neo, Meet Rene: Crash Course Philosophy #5

This week Hank introduces skepticism, exploring everything from the nature of reality through the eyes of a 17th century philosopher and, of course, The Matrix.
--
PBS Digital Studios wants to get to know you better! If you have 10 minutes, we'd really appreciate it AND you'll be entered for a chance to win a t-shirt! https://www.surveymonkey.com/r/pbsds2016
--
Images and video via VideoBlocks or Wikimedia Commons, licensed under Creative Commons by 4.0: https://creativecommons.org/licenses/by/4.0/
"The Matrix" stills copyright 1999 Warner Bros. Entertainment Inc.
“Crowd with Violin Playing” by Freesound user alukahn: http://freesound.org/people/alukahn/sounds/144139/
--
Produced in collaboration with PBS Digital Studios: http://youtube.com/pbsdigitalstudios
Crash Course Philosophy is sponsored by Squarespace.
http://www.squarespace.com/crashcourse
--
Want to find Crash Course elsewhere on the internet?
Facebook - http://www.facebook.com/YouTubeCrashC...
Twitter - http://www.twitter.com/TheCrashCourse
Tumblr - http://thecrashcourse.tumblr.com
Support CrashCourse on Patreon: http://www.patreon.com/crashcourse
CC Kids: http://www.youtube.com/crashcoursekids

07/03/2016